Index: wp-admin/edit.php
===================================================================
--- wp-admin/edit.php	(revision 15432)
+++ wp-admin/edit.php	(working copy)
@@ -106,10 +106,10 @@
 
 				if ( $post_del->post_type == 'attachment' ) {
 					if ( ! wp_delete_attachment($post_id) )
-						wp_die( __('Error in deleting...') );
+						wp_die( __('Error deleting attachment.') );
 				} else {
 					if ( !wp_delete_post($post_id) )
-						wp_die( __('Error in deleting...') );
+						wp_die( __('Error deleting post.') );
 				}
 				$deleted++;
 			}
Index: wp-admin/includes/dashboard.php
===================================================================
--- wp-admin/includes/dashboard.php	(revision 15432)
+++ wp-admin/includes/dashboard.php	(working copy)
@@ -754,7 +754,7 @@
 			$publisher = "<strong>$publisher</strong>";
 
 		$content = $item->get_content();
-		$content = wp_html_excerpt($content, 50) . ' ...';
+		$content = wp_html_excerpt($content, 50) . ' &#8230;';
 
 		if ( $link )
 			/* translators: incoming links feed, %1$s is other person, %3$s is content */
Index: wp-admin/includes/misc.php
===================================================================
--- wp-admin/includes/misc.php	(revision 15432)
+++ wp-admin/includes/misc.php	(working copy)
@@ -225,7 +225,7 @@
 	if ('/' == substr( $short_url, -1 ))
 		$short_url = substr( $short_url, 0, -1 );
 	if ( strlen( $short_url ) > 35 )
-		$short_url = substr( $short_url, 0, 32 ).'...';
+		$short_url = substr( $short_url, 0, 32 ).'&#8230;';
 	return $short_url;
 }
 
Index: wp-admin/includes/template.php
===================================================================
--- wp-admin/includes/template.php	(revision 15432)
+++ wp-admin/includes/template.php	(working copy)
@@ -1804,7 +1804,7 @@
 	if ('/' == substr( $short_url, -1 ))
 		$short_url = substr( $short_url, 0, -1 );
 	if ( strlen( $short_url ) > 35 )
-		$short_url = substr( $short_url, 0, 32 ).'...';
+		$short_url = substr( $short_url, 0, 32 ).'&#8230;';
 	$checkbox = '';
 	// Check if the user for this row is editable
 	if ( current_user_can( 'list_users' ) ) {
@@ -2013,7 +2013,7 @@
 		$author_url = '';
 	$author_url_display = preg_replace('|http://(www\.)?|i', '', $author_url);
 	if ( strlen($author_url_display) > 50 )
-		$author_url_display = substr($author_url_display, 0, 49) . '...';
+		$author_url_display = substr($author_url_display, 0, 49) . '&#8230;';
 
 	$ptime = date('G', strtotime( $comment->comment_date ) );
 	if ( ( abs(time() - $ptime) ) < 86400 )
@@ -2445,7 +2445,7 @@
 ?>
 </select>
 <input class="hide-if-js" type="text" id="metakeyinput" name="metakeyinput" tabindex="7" value="" />
-<a href="#postcustomstuff" class="hide-if-no-js" onclick="jQuery('#metakeyinput, #metakeyselect, #enternew, #cancelnew').toggle();return false;">
+<a href="#postcustomstuff" class="hide-if-no-js" onClick="jQuery('#metakeyinput, #metakeyselect, #enternew, #cancelnew').toggle();return false;">
 <span id="enternew"><?php _e('Enter new'); ?></span>
 <span id="cancelnew" class="hidden"><?php _e('Cancel'); ?></span></a>
 <?php } else { ?>
@@ -3268,7 +3268,7 @@
 				<?php wp_nonce_field( 'find-posts', '_ajax_nonce', false ); ?>
 				<label class="screen-reader-text" for="find-posts-input"><?php _e( 'Search' ); ?></label>
 				<input type="text" id="find-posts-input" name="ps" value="" />
-				<input type="button" onclick="findPosts.send();" value="<?php esc_attr_e( 'Search' ); ?>" class="button" /><br />
+				<input type="button" onClick="findPosts.send();" value="<?php esc_attr_e( 'Search' ); ?>" class="button" /><br />
 
 				<?php
 				$post_types = get_post_types( array('public' => true), 'objects' );
@@ -3284,7 +3284,7 @@
 			<div id="find-posts-response"></div>
 		</div>
 		<div class="find-box-buttons">
-			<input type="button" class="button alignleft" onclick="findPosts.close();" value="<?php esc_attr_e('Close'); ?>" />
+			<input type="button" class="button alignleft" onClick="findPosts.close();" value="<?php esc_attr_e('Close'); ?>" />
 			<input id="find-posts-submit" type="submit" class="button-primary alignright" value="<?php esc_attr_e('Select'); ?>" />
 		</div>
 	</div>
Index: wp-admin/link-manager.php
===================================================================
--- wp-admin/link-manager.php	(revision 15432)
+++ wp-admin/link-manager.php	(working copy)
@@ -187,7 +187,7 @@
 		if ('/' == substr($short_url, -1))
 			$short_url = substr($short_url, 0, -1);
 		if (strlen($short_url) > 35)
-			$short_url = substr($short_url, 0, 32).'...';
+			$short_url = substr($short_url, 0, 32).'&#8230;';
 		$visible = ($link->link_visible == 'Y') ? __('Yes') : __('No');
 		$rating  = $link->link_rating;
 		$style = ($alt % 2) ? '' : ' class="alternate"';
Index: wp-admin/network.php
===================================================================
--- wp-admin/network.php	(revision 15432)
+++ wp-admin/network.php	(working copy)
@@ -96,7 +96,7 @@
 	'<p>' . __('This screen allows you to configure a network as having subdomains (<code>site1.example.com</code>) or subdirectories (<code>example.com/site1</code>). Subdomains require wildcard subdomains to be enabled in Apache and DNS records, if your host allows it.') . '</p>' .
 	'<p>' . __('Choose subdomains or subdirectories; this can only be switched afterwards by reconfiguring your install. Fill out the network details, and click install. If this does not work, you may have to add a wildcard DNS record (for subdomains) or change to another setting in Permalinks (for subdirectories).') . '</p>' .
 	'<p>' . __('The next screen for Network will give you individually-generated lines of code to add to your wp-config.php and .htaccess files. Make sure the settings of your FTP client make files starting with a dot visible, so that you can find .htaccess; you may have to create this file if it really is not there. Make backup copies of those two files.') . '</p>' .
-	'<p>' . __('Add a <code>blogs.dir</code> directory under <code>/wp-content</code> and add the designated lines of code to wp-config.php (just before <code>/*...stop editing...*/</code>) and <code>.htaccess</code> (replacing the existing WordPress rules).') . '</p>' .
+	'<p>' . __('Add a <code>blogs.dir</code> directory under <code>/wp-content</code> and add the designated lines of code to wp-config.php (just before <code>/*&#8230;stop editing&#8230;*/</code>) and <code>.htaccess</code> (replacing the existing WordPress rules).') . '</p>' .
 	'<p>' . __('Refreshing your browser will take you to a screen with an archive of those added lines of code. A set of six links under Super Admin will appear at the top of the main left navigation menu. The multisite network is now enabled.') . '</p>' .
 	'<p>' . __('The choice of subdirectory sites is disabled if this setup is more than a month old because of permalink problems with &#8220;/blog/&#8221; from the main site. This disabling will be addressed soon in a future version.') . '</p>' .
 	'<p><strong>' . __('For more information:') . '</strong></p>' .
Index: wp-admin/press-this.php
===================================================================
--- wp-admin/press-this.php	(revision 15432)
+++ wp-admin/press-this.php	(working copy)
@@ -130,7 +130,7 @@
 			<h3 class="tb"><label for="this_photo_description"><?php _e('Description') ?></label></h3>
 			<div class="titlediv">
 				<div class="titlewrap">
-					<input id="this_photo_description" name="photo_description" class="tbtitle text" onkeypress="if(event.keyCode==13) image_selector();" value="<?php echo esc_attr($title);?>"/>
+					<input id="this_photo_description" name="photo_description" class="tbtitle text" onKeyPress="if(event.keyCode==13) image_selector();" value="<?php echo esc_attr($title);?>"/>
 				</div>
 			</div>
 
@@ -159,13 +159,13 @@
 			<h3 class="tb"><label for="this_photo"><?php _e('URL') ?></label></h3>
 			<div class="titlediv">
 				<div class="titlewrap">
-					<input id="this_photo" name="this_photo" class="tbtitle text" onkeypress="if(event.keyCode==13) image_selector();" />
+					<input id="this_photo" name="this_photo" class="tbtitle text" onKeyPress="if(event.keyCode==13) image_selector();" />
 				</div>
 			</div>
 			<h3 class="tb"><label for="photo_description"><?php _e('Description') ?></label></h3>
 			<div id="titlediv">
 				<div class="titlewrap">
-					<input id="this_photo_description" name="photo_description" class="tbtitle text" onkeypress="if(event.keyCode==13) image_selector();" value="<?php echo esc_attr($title);?>"/>
+					<input id="this_photo_description" name="photo_description" class="tbtitle text" onKeyPress="if(event.keyCode==13) image_selector();" value="<?php echo esc_attr($title);?>"/>
 				</div>
 			</div>
 
@@ -399,7 +399,7 @@
 					jQuery('#waiting').hide();
 					jQuery('#extra-fields').show();
 				}
-				jQuery('#extra-fields').before('<div id="waiting"><img src="<?php echo esc_url( admin_url( 'images/wpspin_light.gif' ) ); ?>" alt="" /> <?php echo esc_js( __( 'Loading...' ) ); ?></div>');
+				jQuery('#extra-fields').before('<div id="waiting"><img src="<?php echo esc_url( admin_url( 'images/wpspin_light.gif' ) ); ?>" alt="" /> <?php echo esc_js( __( 'Loading&#8230;' ) ); ?></div>');
 
 				if(photostorage == false) {
 					jQuery.ajax({
@@ -555,7 +555,7 @@
 	</div>
 	<div class="posting">
 		<?php if ( isset($posted) && intval($posted) ) { $post_ID = intval($posted); ?>
-		<div id="message" class="updated"><p><strong><?php _e('Your post has been saved.'); ?></strong> <a onclick="window.opener.location.replace(this.href); window.close();" href="<?php echo get_permalink( $post_ID); ?>"><?php _e('View post'); ?></a> | <a href="<?php echo get_edit_post_link( $post_ID ); ?>" onclick="window.opener.location.replace(this.href); window.close();"><?php _e('Edit Post'); ?></a> | <a href="#" onclick="window.close();"><?php _e('Close Window'); ?></a></p></div>
+		<div id="message" class="updated"><p><strong><?php _e('Your post has been saved.'); ?></strong> <a onClick="window.opener.location.replace(this.href); window.close();" href="<?php echo get_permalink( $post_ID); ?>"><?php _e('View post'); ?></a> | <a href="<?php echo get_edit_post_link( $post_ID ); ?>" onClick="window.opener.location.replace(this.href); window.close();"><?php _e('Edit Post'); ?></a> | <a href="#" onClick="window.close();"><?php _e('Close Window'); ?></a></p></div>
 		<?php } ?>
 
 		<div id="titlediv">
@@ -581,9 +581,9 @@
 				<li id="switcher">
 					<?php wp_print_scripts( 'quicktags' ); ?>
 					<?php add_filter('the_editor_content', 'wp_richedit_pre'); ?>
-					<a id="edButtonHTML" onclick="switchEditors.go('content', 'html');"><?php _e('HTML'); ?></a>
-					<a id="edButtonPreview" class="active" onclick="switchEditors.go('content', 'tinymce');"><?php _e('Visual'); ?></a>
-					<div class="zerosize"><input accesskey="e" type="button" onclick="switchEditors.go('content')" /></div>
+					<a id="edButtonHTML" onClick="switchEditors.go('content', 'html');"><?php _e('HTML'); ?></a>
+					<a id="edButtonPreview" class="active" onClick="switchEditors.go('content', 'tinymce');"><?php _e('Visual'); ?></a>
+					<div class="zerosize"><input accesskey="e" type="button" onClick="switchEditors.go('content')" /></div>
 				</li>
 				<?php } ?>
 			</ul>
Index: wp-admin/setup-config.php
===================================================================
--- wp-admin/setup-config.php	(revision 15432)
+++ wp-admin/setup-config.php	(working copy)
@@ -132,7 +132,7 @@
 		<tr>
 			<th scope="row"><label for="pwd">Password</label></th>
 			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
-			<td>...and MySQL password.</td>
+			<td>&#8230;and MySQL password.</td>
 		</tr>
 		<tr>
 			<th scope="row"><label for="dbhost">Database Host</label></th>
Index: wp-admin/theme-editor.php
===================================================================
--- wp-admin/theme-editor.php	(revision 15432)
+++ wp-admin/theme-editor.php	(working copy)
@@ -108,7 +108,7 @@
 			$functions = wp_doc_link_parse( $content );
 
 			$docs_select = '<select name="docs-list" id="docs-list">';
-			$docs_select .= '<option value="">' . esc_attr__( 'Function Name...' ) . '</option>';
+			$docs_select .= '<option value="">' . esc_attr__( 'Function Name&#8230;' ) . '</option>';
 			foreach ( $functions as $function ) {
 				$docs_select .= '<option value="' . esc_attr( urlencode( $function ) ) . '">' . htmlspecialchars( $function ) . '()</option>';
 			}
Index: wp-admin/upload.php
===================================================================
--- wp-admin/upload.php	(revision 15432)
+++ wp-admin/upload.php	(working copy)
@@ -88,7 +88,7 @@
 					wp_die( __('You are not allowed to move this post to the trash.') );
 
 				if ( !wp_trash_post($post_id) )
-					wp_die( __('Error in moving to trash...') );
+					wp_die( __('Error moving to trash.') );
 			}
 			$location = add_query_arg( array( 'trashed' => count($post_ids), 'ids' => join(',', $post_ids) ), $location );
 			break;
@@ -98,7 +98,7 @@
 					wp_die( __('You are not allowed to move this post out of the trash.') );
 
 				if ( !wp_untrash_post($post_id) )
-					wp_die( __('Error in restoring from trash...') );
+					wp_die( __('Error restoring from trash.') );
 			}
 			$location = add_query_arg('untrashed', count($post_ids), $location);
 			break;
@@ -108,7 +108,7 @@
 					wp_die( __('You are not allowed to delete this post.') );
 
 				if ( !wp_delete_attachment($post_id_del) )
-					wp_die( __('Error in deleting...') );
+					wp_die( __('Error deleting attachment.') );
 			}
 			$location = add_query_arg('deleted', count($post_ids), $location);
 			break;
Index: wp-content/themes/twentyten/functions.php
===================================================================
--- wp-content/themes/twentyten/functions.php	(revision 15432)
+++ wp-content/themes/twentyten/functions.php	(working copy)
@@ -251,7 +251,7 @@
  * @return string An ellipsis
  */
 function twentyten_auto_excerpt_more( $more ) {
-	return ' &hellip;' . twentyten_continue_reading_link();
+	return ' &#8230;' . twentyten_continue_reading_link();
 }
 add_filter( 'excerpt_more', 'twentyten_auto_excerpt_more' );
 
Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 15432)
+++ wp-includes/comment-template.php	(working copy)
@@ -419,7 +419,7 @@
 	for ($i=0; $i<$k; $i++) {
 		$excerpt .= $blah[$i] . ' ';
 	}
-	$excerpt .= ($use_dotdotdot) ? '...' : '';
+	$excerpt .= ($use_dotdotdot) ? '&#8230;' : '';
 	return apply_filters('get_comment_excerpt', $excerpt);
 }
 
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 15432)
+++ wp-includes/comment.php	(working copy)
@@ -1642,7 +1642,7 @@
 	else
 		$excerpt = apply_filters('the_excerpt', $post->post_excerpt);
 	$excerpt = str_replace(']]>', ']]&gt;', $excerpt);
-	$excerpt = wp_html_excerpt($excerpt, 252) . '...';
+	$excerpt = wp_html_excerpt($excerpt, 252) . '&#8230;';
 
 	$post_title = apply_filters('the_title', $post->post_title);
 	$post_title = strip_tags($post_title);
Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 15432)
+++ wp-includes/deprecated.php	(working copy)
@@ -1704,7 +1704,7 @@
  * @param int $cut Optional. Amount of words to keep for the content.
  * @param int $encode_html Optional. How to encode the content.
  */
-function the_content_rss($more_link_text='(more...)', $stripteaser=0, $more_file='', $cut = 0, $encode_html = 0) {
+function the_content_rss($more_link_text='(more&#8230;)', $stripteaser=0, $more_file='', $cut = 0, $encode_html = 0) {
 	_deprecated_function( __FUNCTION__, '2.9', 'the_content_feed' );
 	$content = get_the_content($more_link_text, $stripteaser, $more_file);
 	$content = apply_filters('the_content_rss', $content);
@@ -1731,7 +1731,7 @@
 		/** @todo Check performance, might be faster to use array slice instead. */
 		for ( $i=0; $i<$k; $i++ )
 			$excerpt .= $blah[$i].' ';
-		$excerpt .= ($use_dotdotdot) ? '...' : '';
+		$excerpt .= ($use_dotdotdot) ? '&#8230;' : '';
 		$content = $excerpt;
 	}
 	$content = str_replace(']]>', ']]&gt;', $content);
Index: wp-includes/formatting.php
===================================================================
--- wp-includes/formatting.php	(revision 15432)
+++ wp-includes/formatting.php	(working copy)
@@ -1831,7 +1831,7 @@
 		$text = str_replace(']]>', ']]&gt;', $text);
 		$text = strip_tags($text);
 		$excerpt_length = apply_filters('excerpt_length', 55);
-		$excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
+		$excerpt_more = apply_filters('excerpt_more', ' ' . '[&#8230;]');
 		$words = preg_split("/[\n\r\t ]+/", $text, $excerpt_length + 1, PREG_SPLIT_NO_EMPTY);
 		if ( count($words) > $excerpt_length ) {
 			array_pop($words);
Index: wp-includes/general-template.php
===================================================================
--- wp-includes/general-template.php	(revision 15432)
+++ wp-includes/general-template.php	(working copy)
@@ -1995,7 +1995,7 @@
 				$page_links[] = "<a class='page-numbers' href='" . esc_url( apply_filters( 'paginate_links', $link ) ) . "'>$n_display</a>";
 				$dots = true;
 			elseif ( $dots && !$show_all ) :
-				$page_links[] = "<span class='page-numbers dots'>...</span>";
+				$page_links[] = "<span class='page-numbers dots'>&#8230;</span>";
 				$dots = false;
 			endif;
 		endif;
Index: wp-includes/js/tinymce/langs/wp-langs-en.js
===================================================================
--- wp-includes/js/tinymce/langs/wp-langs-en.js	(revision 15432)
+++ wp-includes/js/tinymce/langs/wp-langs-en.js	(working copy)
@@ -47,7 +47,7 @@
 forward_desc:"Move forward",
 backward_desc:"Move backward",
 absolute_desc:"Toggle absolute positioning",
-content:"New layer..."
+content:"New layer&#8230;"
 },
 save:{
 save_desc:"Save",
@@ -146,7 +146,7 @@
 ignore_word:"Ignore word",
 ignore_words:"Ignore all",
 langs:"Languages",
-wait:"Please wait...",
+wait:"Please wait&#8230;",
 sug:"Suggestions",
 no_sug:"No suggestions",
 no_mpell:"No misspellings found."
@@ -384,8 +384,8 @@
 wp_more_desc:"Insert More tag (Alt+Shift+T)",
 wp_page_desc:"Insert Page break (Alt+Shift+P)",
 wp_help_desc:"Help (Alt+Shift+H)",
-wp_more_alt:"More...",
-wp_page_alt:"Next page...",
+wp_more_alt:"More&#8230;",
+wp_page_alt:"Next page&#8230;",
 add_media:"Add Media",
 add_image:"Add an Image",
 add_video:"Add Video",
Index: wp-includes/js/tinymce/langs/wp-langs.php
===================================================================
--- wp-includes/js/tinymce/langs/wp-langs.php	(revision 15432)
+++ wp-includes/js/tinymce/langs/wp-langs.php	(working copy)
@@ -70,7 +70,7 @@
 forward_desc:"' . mce_escape( __('Move forward') ) . '",
 backward_desc:"' . mce_escape( __('Move backward') ) . '",
 absolute_desc:"' . mce_escape( __('Toggle absolute positioning') ) . '",
-content:"' . mce_escape( __('New layer...') ) . '"
+content:"' . mce_escape( __('New layer&#8230;') ) . '"
 },
 save:{
 save_desc:"' . mce_escape( __('Save') ) . '",
@@ -169,7 +169,7 @@
 ignore_word:"' . mce_escape( __('Ignore word') ) . '",
 ignore_words:"' . mce_escape( __('Ignore all') ) . '",
 langs:"' . mce_escape( __('Languages') ) . '",
-wait:"' . mce_escape( __('Please wait...') ) . '",
+wait:"' . mce_escape( __('Please wait&#8230;') ) . '",
 sug:"' . mce_escape( __('Suggestions') ) . '",
 no_sug:"' . mce_escape( __('No suggestions') ) . '",
 no_mpell:"' . mce_escape( __('No misspellings found.') ) . '"
@@ -407,8 +407,8 @@
 wp_more_desc:"' . mce_escape( __('Insert More Tag') ) . ' (Alt+Shift+T)",
 wp_page_desc:"' . mce_escape( __('Insert Page break') ) . ' (Alt+Shift+P)",
 wp_help_desc:"' . mce_escape( __('Help') ) . ' (Alt+Shift+H)",
-wp_more_alt:"' . mce_escape( __('More...') ) . '",
-wp_page_alt:"' . mce_escape( __('Next page...') ) . '",
+wp_more_alt:"' . mce_escape( __('More&#8230;') ) . '",
+wp_page_alt:"' . mce_escape( __('Next page&#8230;') ) . '",
 add_media:"' . mce_escape( __('Add Media') ) . '",
 add_image:"' . mce_escape( __('Add an Image') ) . '",
 add_video:"' . mce_escape( __('Add Video') ) . '",
Index: wp-includes/pluggable.php
===================================================================
--- wp-includes/pluggable.php	(revision 15432)
+++ wp-includes/pluggable.php	(working copy)
@@ -1042,7 +1042,7 @@
 		/* translators: 1: comment author, 2: author IP, 3: author domain */
 		$notify_message .= sprintf( __('Website: %1$s (IP: %2$s , %3$s)'), $comment->comment_author, $comment->comment_author_IP, $comment_author_domain ) . "\r\n";
 		$notify_message .= sprintf( __('URL    : %s'), $comment->comment_author_url ) . "\r\n";
-		$notify_message .= __('Excerpt: ') . "\r\n" . sprintf('[...] %s [...]', $comment->comment_content ) . "\r\n\r\n";
+		$notify_message .= __('Excerpt: ') . "\r\n" . sprintf('[&#8230;] %s [&#8230;]', $comment->comment_content ) . "\r\n\r\n";
 		$notify_message .= __('You can see all pingbacks on this post here: ') . "\r\n";
 		/* translators: 1: blog name, 2: post title */
 		$subject = sprintf( __('[%1$s] Pingback: "%2$s"'), $blogname, $post->post_title );
Index: wp-includes/post-template.php
===================================================================
--- wp-includes/post-template.php	(revision 15432)
+++ wp-includes/post-template.php	(working copy)
@@ -184,7 +184,7 @@
 	global $id, $post, $more, $page, $pages, $multipage, $preview;
 
 	if ( null === $more_link_text )
-		$more_link_text = __( '(more...)' );
+		$more_link_text = __( '(more&#8230;)' );
 
 	$output = '';
 	$hasTeaser = false;
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 15432)
+++ wp-includes/post.php	(working copy)
@@ -2827,7 +2827,7 @@
 		$excerpt = strip_tags($post_excerpt ? $post_excerpt : $post_content);
 
 		if (strlen($excerpt) > 255) {
-			$excerpt = substr($excerpt,0,252) . '...';
+			$excerpt = substr($excerpt,0,252) . '&#8230;';
 		}
 
 		$trackback_urls = explode(',', $tb_list);
Index: wp-includes/script-loader.php
===================================================================
--- wp-includes/script-loader.php	(revision 15432)
+++ wp-includes/script-loader.php	(working copy)
@@ -379,7 +379,7 @@
 		$scripts->add_data( 'set-post-thumbnail', 'group', 1 );
 		$scripts->localize( 'set-post-thumbnail', 'setPostThumbnailL10n', array(
 			'setThumbnail' => __( 'Use as featured image' ),
-			'saving' => __( 'Saving...' ),
+			'saving' => __( 'Saving&#8230;' ),
 			'error' => __( 'Could not set that as the thumbnail image. Try a different attachment.' ),
 			'done' => __( 'Done' )
 		) );
Index: wp-login.php
===================================================================
--- wp-login.php	(revision 15432)
+++ wp-login.php	(working copy)
@@ -205,7 +205,7 @@
 	$message = apply_filters('retrieve_password_message', $message, $key);
 
 	if ( $message && !wp_mail($user_email, $title, $message) )
-		wp_die( __('The e-mail could not be sent.') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function...') );
+		wp_die( __('The e-mail could not be sent.') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function.') );
 
 	return true;
 }
@@ -257,7 +257,7 @@
 	$message = apply_filters('password_reset_message', $message, $new_pass);
 
 	if ( $message && !wp_mail($user->user_email, $title, $message) )
-  		wp_die( __('The e-mail could not be sent.') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function...') );
+  		wp_die( __('The e-mail could not be sent.') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function.') );
 
 	wp_password_change_notification($user);
 
@@ -307,7 +307,7 @@
 	$user_pass = wp_generate_password();
 	$user_id = wp_create_user( $sanitized_user_login, $user_pass, $user_email );
 	if ( ! $user_id ) {
-		$errors->add( 'registerfail', sprintf( __( '<strong>ERROR</strong>: Couldn&#8217;t register you... please contact the <a href="mailto:%s">webmaster</a> !' ), get_option( 'admin_email' ) ) );
+		$errors->add( 'registerfail', sprintf( __( '<strong>ERROR</strong>: Couldn&#8217;t register your account. Please contact the <a href="mailto:%s">webmaster</a> !' ), get_option( 'admin_email' ) ) );
 		return $errors;
 	}
 
Index: wp-trackback.php
===================================================================
--- wp-trackback.php	(revision 15432)
+++ wp-trackback.php	(working copy)
@@ -87,8 +87,8 @@
 	if ( !pings_open($tb_id) )
 		trackback_response(1, 'Sorry, trackbacks are closed for this item.');
 
-	$title =  wp_html_excerpt( $title, 250 ).'...';
-	$excerpt = wp_html_excerpt( $excerpt, 252 ).'...';
+	$title =  wp_html_excerpt( $title, 250 ).'&#8230;';
+	$excerpt = wp_html_excerpt( $excerpt, 252 ).'&#8230;';
 
 	$comment_post_ID = (int) $tb_id;
 	$comment_author = $blog_name;
Index: xmlrpc.php
===================================================================
--- xmlrpc.php	(revision 15432)
+++ xmlrpc.php	(working copy)
@@ -3252,7 +3252,7 @@
 
 				// prevent really long link text
 				if ( strlen($context[1]) > 100 )
-					$context[1] = substr($context[1], 0, 100) . '...';
+					$context[1] = substr($context[1], 0, 100) . '&#8230;';
 
 				$marker = '<wpcontext>'.$context[1].'</wpcontext>';    // set up our marker
 				$excerpt= str_replace($context[0], $marker, $excerpt); // swap out the link for our marker
@@ -3270,7 +3270,7 @@
 
 		$pagelinkedfrom = str_replace('&', '&amp;', $pagelinkedfrom);
 
-		$context = '[...] ' . esc_html( $excerpt ) . ' [...]';
+		$context = '[&#8230;] ' . esc_html( $excerpt ) . ' [&#8230;]';
 		$pagelinkedfrom = $wpdb->escape( $pagelinkedfrom );
 
 		$comment_post_ID = (int) $post_ID;

Index: wp-includes/default-widgets.php
===================================================================
--- wp-includes/default-widgets.php	(revision 15432)
+++ wp-includes/default-widgets.php	(working copy)
@@ -820,11 +820,11 @@
 		$desc = str_replace( array("\n", "\r"), ' ', esc_attr( strip_tags( @html_entity_decode( $item->get_description(), ENT_QUOTES, get_option('blog_charset') ) ) ) );
 		$desc = wp_html_excerpt( $desc, 360 );
 
 		// Append ellipsis. Change existing [...] to [&hellip;].
 		if ( '[...]' == substr( $desc, -5 ) )
 			$desc = substr( $desc, 0, -5 ) . '[&hellip;]';
-		elseif ( '[&hellip;]' != substr( $desc, -10 ) )
-			$desc .= ' [&hellip;]';
+		elseif ( '[&#8230;]' != substr( $desc, -10 ) )
+			$desc .= ' [&#8230;]';
 
 		$desc = esc_html( $desc );
 
@@ -820,11 +820,11 @@
 		$desc = wp_html_excerpt( $desc, 360 );
 
-		// Append ellipsis. Change existing [...] to [&hellip;].
+		// Append ellipsis. Change existing [...] to [&#8230;].
 		if ( '[...]' == substr( $desc, -5 ) )
 			$desc = substr( $desc, 0, -5 ) . '[&hellip;]';